==> mozilla_1.0.0.orig.tar.gz: mozilla/modules/plugin/tools/sdk/samples/scriptable/mac/plugin.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __PLUGIN_H__
#define __PLUGIN_H__

#include "pluginbase.h"
#include "nsScriptablePeer.h"

class nsPluginInstance : public nsPluginInstanceBase
{
public:
  nsPluginInstance(NPP aInstance);
  ~nsPluginInstance();

  NPBool init(NPWindow* aWindow);
  void shut();
  NPBool isInitialized();
  NPError SetWindow(NPWindow* pNPWindow);
  uint16  HandleEvent(void* event);
  NPError	GetValue(NPPVariable variable, void *value);

  void showVersion();
  void clear();
  nsIScriptablePlugin* getScriptablePeer();  

  char mString[128];

private:
  // locals
  void DoDraw();
  NPBool StartDraw(NPWindow* window);
  void EndDraw(NPWindow* window);
  void DrawString(const unsigned char* text, short width, short height, short centerX, Rect drawRect);

  nsIScriptablePlugin * mScriptablePeer;
  
  NPWindow * mWindow;
  NPP mInstance;
  NPBool mInitialized;
  GrafPtr mSavePort;
  RgnHandle mSaveClip;
  Rect mRevealedRect;
  short mSavePortTop;
  short mSavePortLeft;
};

#endif // __PLUGIN_H__

==> mozilla_1.7.13.orig.tar.gz: mozilla/modules/plugin/tools/sdk/samples/scriptable/mac/plugin.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __PLUGIN_H__
#define __PLUGIN_H__

#include "pluginbase.h"
#include "nsScriptablePeer.h"

class nsPluginInstance : public nsPluginInstanceBase
{
public:
  nsPluginInstance(NPP aInstance);
  ~nsPluginInstance();

  NPBool init(NPWindow* aWindow);
  void shut();
  NPBool isInitialized();
  NPError SetWindow(NPWindow* pNPWindow);
  uint16  HandleEvent(void* event);
  NPError	GetValue(NPPVariable variable, void *value);

  void showVersion();
  void clear();
  nsScriptablePeer* getScriptablePeer();  

  char mString[128];

private:
  // locals
  void DoDraw();
  NPBool StartDraw(NPWindow* window);
  void EndDraw(NPWindow* window);
  void DrawString(const unsigned char* text, short width, short height, short centerX, Rect drawRect);

  nsScriptablePeer * mScriptablePeer;
  
  NPWindow * mWindow;
  NPP mInstance;
  NPBool mInitialized;
  GrafPtr mSavePort;
  RgnHandle mSaveClip;
  Rect mRevealedRect;
  short mSavePortTop;
  short mSavePortLeft;
};

#endif // __PLUGIN_H__
